pascual » FAQ

# PAScual Frequently Asked Questions (FAQ)

## General

1. ### What is PAScual?

   PAScual is a program (or more precisely, a suite of programs) for analysing Positron Annihilation Lifetime Spectroscopy (PALS) spectra.

2. ### How much does PAScual cost?

   Nothing. It is free. Furthermore, it is free as in 'freedom'. Its source code is available under the General Public License for everybody to study it, modify it, etc.

3. ### If everybody can see the code, what prevents competing programs to steal the ideas in PAScual?

   The answer is that I don't see other programs as "competitors". I hope that PAScual is useful for everybody. I also expect that if someone finds PAScual useful, will acknowledge it by, e.g., citing it. If other programs want to use some idea in my code, they are welcome (although if they use the code directly, they should respect the terms of the license. Anyway, I used other people's ideas (written in articles) when implementing PAScual.

4. ### What does the name 'PAScual' stand for?

   One could pretend that 'PAScual' stands for something like 'Positron Annihilation Spectroscopy controlled universal analysis layer', but the fact is that it is just a pretentious way of playing with the author's family name.

5. ### What is the intended schedule for new versions?

   I currently work in PAScual as part of my research activity. However, I will be changing my field soon and my time devoted to PAScual will be considerably less. Therefore my objective is to leave PAScual in a stable state that can be used without problems. This was the objective for the version 1.x series and is already pretty much accomplished (e.g. from version 1.2). The idea is to give the final polishing to the interface in the 1.x series and leave model/physics implementations for a future 2.x series. If you need some feature, request it or, if you can, implement it yourself (remember that the source code is open).

## Installation

1. ### What do I need to use PAScual?

   PAScual is written in Python. This means that you need to install a Python interpreter. PAScual also makes use of Scipy so you need to have that installed as well. Finally, You will need the Qt libraries and PyQt if you want to use the graphical user interface. Matplotlib is needed only if you want to generate graphics from the command line interface. Make sure you read the Installation section of the User Manual to get the most comprehensive information regarding to the required packages.

2. ### Where can I download PAScual?

   Surprisingly, this can be done by following the link called Download. In general, you should download and install the latest available version.

3. ### Where can I get some information about installing/using PAScual?

   The main source of information is the User Manual.You may also want to have a look at the documentation section. Finally, don't forget that PAScual is Free (as in freedom), so you can read its source code if you really want to know what's going on. Of course, you can also ask the author for help.

## Using PAScual

1. ### Does PAScual support source corrections?

   Yes, but not in a explicit way. The reason is that a source correction is, simply, one or more components (probably with fixed intensity and lifetime). Since in PAScual you can fix any parameter, you can introduce source correction components. Some programs choose to separate them them from the rest of components and not count them for the intensity total. I don't do that in PAScual because I prefer to see them just like another component in the spectrum. See the discussion in the user manual regarding to this. Of course, if you really want PAScual to not count the source intensity in the total, just ask the author for this feature (or implement it yourself).

1. ### Does PAScual support complex components?

   Not yet, but... Pascual does not yet support Gaussian spread components, although the code has been written with them in mind and introducing them should be easy. A different module, called gridpals has already been implemented for analysis in a pseudo-continuous mode (MELT-like style). See FAQ.

1. ### Does Pascual support non-Gaussian resolution functions?

   Not yet, but... Part of the work for supporting a more complex resolution function (Gaussian+exponential tails) is already done, but not finished. See FAQ.

## Bugs/errors

1. ### PAScual crashes/does not work... what should I do?

   First, make sure you have all the required packages installed. Also make sure you download the latest stable version. Then try to reproduce the examples in the User Manual. If these fail, contact the author. If the problem is with your own data, please contact the author sending:
   - a detailed description of the problem
   - the details of your installation (operative system), version of PAScual and of the required packages
   - A list of the steps needed to reproduce the error
   - the data that causes the trouble

2. ### I found a problem/bug in PAScual. How do I report it?

   At this moment no formal bug reporting procedure is established. Just contact the author.

3. ### I solved a bug (or added a feature) in PAScual. Are you interested in my solution?

   Definitely!. Please send the code or the patch to the author. Of course, credits will be given. Also, if you are capable of programming and want to get involved in developing PAScual, you are more than welcome to do it. Just contact the author.